# Systemd-py
`systemd-py` is a library which helps you to create systemd services in python.


## Installation
### Install from PyPI
    pip install systemd-py

### Install from source (build using poetry)
    git clone
    cd systemd-py
    poetry build
    pip install dist/systemd-py-<version>-py3-none-any.whl

### Install from GitHub
    pip install git+hhttps://github.com/amiwrprez/systemd-py.git


## Documentation
### Online
See [documentation](https://amiwrpremium.github.io/systemd-py/).

### Offline
You can generate documentation locally using `mkdocs`:
    mkdocs build


## Examples
### From docs
See [Documentation Examples](https://amiwrpremium.github.io/systemd-py/examples/)
### Example Folder
See [examples](https://github.com/amiwrpremium/systemd-py/tree/master/examples) for examples.
